@@ -5,7 +5,7 @@ package Data::Tubes;
 use strict;
 use warnings;
 use English qw< -no_match_vars >;
-our $VERSION = '0.733';
+our $VERSION = '0.735';
 use Exporter qw< import >;
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first LOGLEVEL >;
@@ -59,6 +59,19 @@ sub pipeline {
          return (records => \@records);
         }
         if $tap eq 'bucket';
+      $tap = sub {
+         my ($record) = $_[0]->();
+         return $record;
+        }
+        if $tap eq 'first';
+      $tap = sub {
+         my $iterator = shift;
+         my @records;
+         while (my @items = $iterator->()) { push @records, @items; }
+         return unless @records;
+         return \@records;
+        }
+        if $tap eq 'array';
    }
 
    if ((!defined($tap)) && (defined($args->{pump}))) {
