@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use English qw< -no_match_vars >;
 use Exporter 'import';
-our $VERSION = '0.733';
+our $VERSION = '0.735';
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 
@@ -429,8 +429,11 @@ sub trim {
 }
 
 sub tube {
+   my $opts = {};
+   $opts = shift(@_) if (@_ && ref($_[0]) eq 'HASH');
+   my @prefix = exists($opts->{prefix}) ? ($opts->{prefix}) : ();
    my $locator = shift;
-   return load_sub($locator)->(@_);
+   return load_sub($locator, @prefix)->(@_);
 }
 
 sub unzip {
